@@ -7,7 +7,11 @@ sanitize_shape <- function(shape) {
         return(term + statistic ~ model)
     }
 
-    checkmate::assert_formula(shape, null.ok = TRUE)
+    checkmate::assert(
+        checkmate::check_null(shape),
+        checkmate::check_formula(shape),
+        checkmate::check_choice(shape, choices = "rbind")
+    )
 
     # interactions with ":" are used to combine columns
     shape_cha <- deparse(shape)
@@ -18,7 +22,7 @@ sanitize_shape <- function(shape) {
     combine <- unlist(regmatches(shape_cha, gregexpr(regex, shape_cha)))
 
     # remove interactions from the formula since we are going to combine them in get_estimates
-    for (com in combine) { 
+    for (com in combine) {
         shape_cha <- gsub(com, gsub(":.*", "", com), shape_cha, fixed = TRUE)
     }
     shape <- stats::as.formula(shape_cha)
@@ -34,14 +38,6 @@ sanitize_shape <- function(shape) {
 
     if (length(group_name) == 0) {
         group_name <- NULL
-    } else if (length(group_name) == 1) {
-        lhs[lhs == group_name] <- "group"
-        rhs[rhs == group_name] <- "group"
-    } else {
-        msg <- format_msg(
-        'The `shape` formula can only include one group name. The other terms must be:
-        "term", "model", or "statistic".')
-        stop(msg, call. = FALSE)
     }
 
     # partial formulas
