@@ -1,5 +1,3 @@
-library(modelsummary)
-
 test_that("multiple models must be wrapped in a list", {
     mod <- lm(mpg ~ hp, mtcars)
     expect_error(modelplot(mod, mod), regexp = "is sometimes raised")
@@ -14,7 +12,8 @@ test_that("coef_map: two variables with the same name within or between models",
   y <- rnorm(100)
   z <- rnorm(100)
   mod <- lm(y ~ x + z)
-  expect_warning(modelsummary(mod, "data.frame", coef_map = c('x' = 'X', 'z' = 'X')))
+  expect_error(modelsummary(mod, "data.frame", coef_map = c('x' = 'X', 'z' = 'X')))
+  expect_error(modelsummary(mod, "data.frame", coef_rename = c('x' = 'X', 'z' = 'X')))
   # across models works well
   mod <- list()
   mod[[1]] <- lm(y ~ x)
