@@ -11,11 +11,12 @@ test_that("exponentiate is a flag", {
 test_that("logit coefficients exponentiate", {
 
     tab <- modelsummary(fit, gof_omit = ".*", estimate = "estimate", statistic = NULL, output = "dataframe", exponentiate = TRUE)
-    x <- c("0.0002", "1.448", "2.078", "2.017")
+    x <- c("0.000", "1.448", "2.078", "2.017")
     expect_equal(tab[[4]], x)
+    tab <- modelsummary(fit, gof_omit = ".*", estimate = "estimate", statistic = NULL, output = "dataframe", exponentiate = TRUE)
 
     tab <- modelsummary(fit, gof_omit = ".*", estimate = "conf.low", statistic = NULL, output = "dataframe", exponentiate = TRUE)
-    x <- c("2e-09", "1.026", "0.130", "0.044")
+    x <- c("0.000", "1.026", "0.130", "0.044")
     expect_equal(tab[[4]], x)
 
     tab <- modelsummary(fit, gof_omit = ".*", estimate = "conf.high", statistic = NULL, output = "dataframe", exponentiate = TRUE)
@@ -30,7 +31,7 @@ test_that("vcov", {
     requiet("sandwich")
     b <- coef(fit)
     se  <- sqrt(diag(vcovCL(fit, ~cyl)))
-    x <- c("0.0002", "1.448", "2.078", "2.017")
+    x <- c("0.000", "1.448", "2.078", "2.017")
     tab <- modelsummary(fit, vcov = ~cyl, gof_omit = ".*", estimate = "estimate",
                         statistic = NULL, output = "dataframe",
                         exponentiate = TRUE)
@@ -51,23 +52,23 @@ test_that("exponentiate vector", {
     # coefficients
     tab <- modelsummary(mod, exponentiate = FALSE,
                         output = "data.frame", statistic = NULL, fmt = identity)
-    expect_equal(b, as.numeric(tab[["Model 1"]][1:2]), ignore_attr = TRUE)
-    expect_equal(b, as.numeric(tab[["Model 2"]][1:2]), ignore_attr = TRUE)
+    expect_equal(b, as.numeric(tab[["(1)"]][1:2]), ignore_attr = TRUE)
+    expect_equal(b, as.numeric(tab[["(2)"]][1:2]), ignore_attr = TRUE)
 
     tab <- modelsummary(mod, exponentiate = TRUE,
                         output = "data.frame", statistic = NULL, fmt = identity)
-    expect_equal(exp(b), as.numeric(tab[["Model 1"]][1:2]), ignore_attr = TRUE)
-    expect_equal(exp(b), as.numeric(tab[["Model 2"]][1:2]), ignore_attr = TRUE)
+    expect_equal(exp(b), as.numeric(tab[["(1)"]][1:2]), ignore_attr = TRUE)
+    expect_equal(exp(b), as.numeric(tab[["(2)"]][1:2]), ignore_attr = TRUE)
 
     # standard error
     tab <- modelsummary(mod, exponentiate = TRUE, output = "data.frame",
                         estimate = "std.error", statistic = NULL, fmt = identity)
-    expect_equal(exp(b) * se, as.numeric(tab[["Model 1"]][1:2]), ignore_attr = TRUE)
-    expect_equal(exp(b) * se, as.numeric(tab[["Model 2"]][1:2]), ignore_attr = TRUE)
+    expect_equal(exp(b) * se, as.numeric(tab[["(1)"]][1:2]), ignore_attr = TRUE)
+    expect_equal(exp(b) * se, as.numeric(tab[["(2)"]][1:2]), ignore_attr = TRUE)
 
     # vector
     tab <- modelsummary(mod, exponentiate = c(TRUE, FALSE),
                         output = "data.frame", statistic = NULL, fmt = identity)
-    expect_equal(exp(b), as.numeric(tab[["Model 1"]][1:2]), ignore_attr = TRUE)
-    expect_equal(b, as.numeric(tab[["Model 2"]][1:2]), ignore_attr = TRUE)
+    expect_equal(exp(b), as.numeric(tab[["(1)"]][1:2]), ignore_attr = TRUE)
+    expect_equal(b, as.numeric(tab[["(2)"]][1:2]), ignore_attr = TRUE)
 })
